/*
 *  Copyright (C) 2021 Texas Instruments Incorporated
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <drivers/i2c.h>
#include <kernel/dpl/DebugP.h>
#include "ti_drivers_config.h"
#include "ti_drivers_open_close.h"
#include "ti_board_open_close.h"
#include <drivers/i2c.h>
#include <stdio.h>


static void i2c_read_error_handler(int32_t status);

void empty_main(void *arg0)
{
    int32_t         status = SystemP_SUCCESS;
    printf("\nstatus: %c", status);
    I2C_Handle      i2cHandle;
    uint8_t buffer[2] = {0};

    /* STEP 1:
     *
     * Opening drivers, I2C being one of them.
     */

    /* STEP 2:
     *
     * Initializes I2C Handle.
     */
    i2cHandle = gI2cHandle[CONFIG_I2C0];

    /* STEP 3:
     *
     * Suppose our usecase is to set PIN number 16 to Output Mode, then we need to
     * write to Configuration Registers more specifically Configuration Port 1.
     * Configuration Port 1 is at 0x0D and the default value of this port is b"11111111"
     * We need to set the 6th bit to 0. So the value to write would be b"10111111" which is 0xBF.
     */
    buffer[0] = 0x0D;
    buffer[1] = 0xBF;

    I2C_Transaction i2cTransaction;
    I2C_Transaction_init(&i2cTransaction);
    i2cTransaction.slaveAddress = 0x22;
    i2cTransaction.writeBuf = buffer;
    i2cTransaction.writeCount = 2;
    status = I2C_transfer(i2cHandle, &i2cTransaction);
    i2c_read_error_handler(status);
    DebugP_assert(SystemP_SUCCESS == status);
    printf("\n%d", status);

}

static void i2c_read_error_handler(int32_t status)
{
    switch(status)
    {
        case I2C_STS_ERR:
            DebugP_logError("\nGeneric error occurred");
            break;
        case I2C_STS_ERR_TIMEOUT:
            DebugP_logError("Timeout error occurred\n");
            break;
        case I2C_STS_ERR_NO_ACK:
            DebugP_logError("No acknowledgement received\n");
            break;
        case I2C_STS_ERR_ARBITRATION_LOST:
            DebugP_logError("Sample Arbitration lost\n");
            break;
        case I2C_STS_ERR_ACCESS_ERROR:
            DebugP_logError("Bus Access error occurred\n");
            break;
    }

    return;
}
